@@ -122,7 +122,8 @@ def merge_config(args, default_args): # pragma: no cover
         # Config options overwrite default options
         config_getter = None
         if name in ['html', 'termcolor', 'notermcolor', 'help', 'logging',
-                'version', 'run_coverage']:
+                'version', 'run_coverage', 'options', 'completions',
+                'completion_file']:
             config_getter = config.getboolean
         elif name in ['subprocesses', 'debug', 'verbose']:
             config_getter = config.getint
